# Copyright (c) 2017-2021 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: com/daml/ledger/api/v1/version_service.proto

from google.protobuf import (
    descriptor as _descriptor,
    message as _message,
    reflection as _reflection,
    symbol_database as _symbol_database,
)

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor.FileDescriptor(
    name="com/daml/ledger/api/v1/version_service.proto",
    package="com.daml.ledger.api.v1",
    syntax="proto3",
    serialized_options=b"\n\026com.daml.ledger.api.v1B\030VersionServiceOuterClass\252\002\026Com.Daml.Ledger.Api.V1",
    create_key=_descriptor._internal_create_key,
    serialized_pb=b'\n,com/daml/ledger/api/v1/version_service.proto\x12\x16\x63om.daml.ledger.api.v1"/\n\x1aGetLedgerApiVersionRequest\x12\x11\n\tledger_id\x18\x01 \x01(\t".\n\x1bGetLedgerApiVersionResponse\x12\x0f\n\x07version\x18\x01 \x01(\t2\x90\x01\n\x0eVersionService\x12~\n\x13GetLedgerApiVersion\x12\x32.com.daml.ledger.api.v1.GetLedgerApiVersionRequest\x1a\x33.com.daml.ledger.api.v1.GetLedgerApiVersionResponseBK\n\x16\x63om.daml.ledger.api.v1B\x18VersionServiceOuterClass\xaa\x02\x16\x43om.Daml.Ledger.Api.V1b\x06proto3',
)


_GETLEDGERAPIVERSIONREQUEST = _descriptor.Descriptor(
    name="GetLedgerApiVersionRequest",
    full_name="com.daml.ledger.api.v1.GetLedgerApiVersionRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="ledger_id",
            full_name="com.daml.ledger.api.v1.GetLedgerApiVersionRequest.ledger_id",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=72,
    serialized_end=119,
)


_GETLEDGERAPIVERSIONRESPONSE = _descriptor.Descriptor(
    name="GetLedgerApiVersionResponse",
    full_name="com.daml.ledger.api.v1.GetLedgerApiVersionResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="version",
            full_name="com.daml.ledger.api.v1.GetLedgerApiVersionResponse.version",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=121,
    serialized_end=167,
)

DESCRIPTOR.message_types_by_name["GetLedgerApiVersionRequest"] = _GETLEDGERAPIVERSIONREQUEST
DESCRIPTOR.message_types_by_name["GetLedgerApiVersionResponse"] = _GETLEDGERAPIVERSIONRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetLedgerApiVersionRequest = _reflection.GeneratedProtocolMessageType(
    "GetLedgerApiVersionRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _GETLEDGERAPIVERSIONREQUEST,
        "__module__": "com.daml.ledger.api.v1.version_service_pb2"
        # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.GetLedgerApiVersionRequest)
    },
)
_sym_db.RegisterMessage(GetLedgerApiVersionRequest)

GetLedgerApiVersionResponse = _reflection.GeneratedProtocolMessageType(
    "GetLedgerApiVersionResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _GETLEDGERAPIVERSIONRESPONSE,
        "__module__": "com.daml.ledger.api.v1.version_service_pb2"
        # @@protoc_insertion_point(class_scope:com.daml.ledger.api.v1.GetLedgerApiVersionResponse)
    },
)
_sym_db.RegisterMessage(GetLedgerApiVersionResponse)


DESCRIPTOR._options = None

_VERSIONSERVICE = _descriptor.ServiceDescriptor(
    name="VersionService",
    full_name="com.daml.ledger.api.v1.VersionService",
    file=DESCRIPTOR,
    index=0,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
    serialized_start=170,
    serialized_end=314,
    methods=[
        _descriptor.MethodDescriptor(
            name="GetLedgerApiVersion",
            full_name="com.daml.ledger.api.v1.VersionService.GetLedgerApiVersion",
            index=0,
            containing_service=None,
            input_type=_GETLEDGERAPIVERSIONREQUEST,
            output_type=_GETLEDGERAPIVERSIONRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
)
_sym_db.RegisterServiceDescriptor(_VERSIONSERVICE)

DESCRIPTOR.services_by_name["VersionService"] = _VERSIONSERVICE

# @@protoc_insertion_point(module_scope)
