# Copyright (c) 2017-2021 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0

"""
This module has been relocated to ``dazl.client.events`` or ``dazl.damlast.lookup``.
"""

__all__ = ["validate_template", "template_reverse_globs"]

from ..client.events import template_reverse_globs
from ..damlast.lookup import validate_template
